part of 'exercise_execute_plan_bloc.dart';

@immutable
abstract class ExerciseExecutePlanState extends Equatable {
  const ExerciseExecutePlanState();

  @override
  List<Object> get props => [];
}

class ExerciseByPlanStateInitial extends ExerciseExecutePlanState {
  const ExerciseByPlanStateInitial();
}

class ExerciseByPlanLoading extends ExerciseExecutePlanState {
  const ExerciseByPlanLoading();
}

// updated screen
class ExerciseByPlanReady extends ExerciseExecutePlanState {
  const ExerciseByPlanReady();
}

// error splash screen
class ExerciseByPlanError extends ExerciseExecutePlanState {
  final String message;
  const ExerciseByPlanError({required this.message});

  @override
  List<Object> get props => [message];
}
